import * as React from "react";
import {observer} from "mobx-react-lite";
import {makeStyles} from "@material-ui/core/styles";
import {Button} from "@material-ui/core";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faUpload} from "@rx-suite/pro-solid-svg-icons";
import {Trans} from "@lingui/macro";

export type FileUploadProps = {
    onChange: (e: any) => void;
};

const useStyles = makeStyles(theme => ({
    root: {
        padding: '4px 4px',
        display: 'flex',
        alignItems: 'center',
        width: 400,
    },
    input: {
        flex: 1,
    },
    iconButton: {
        marginLeft: theme.spacing(1),
        marginRight: theme.spacing(1)
    }
}));

export const FileUpload: React.FunctionComponent<FileUploadProps> = observer(({onChange}) => {
    const classes = useStyles();

    const onChangeHandler = React.useCallback((event) => {
        if (event.target.files[0]) {
            if (parseFloat(event.target.files[0].size) > 262144000) {
                alert("File size must be no more than 25MB");
            } else {
                onChange(event);
            }
        }
    }, [onChange]);

    return (
        <React.Fragment>
            <input
                className={classes.input}
                id="raised-button-file"
                multiple
                type="file"
                accept="image/*"
                onChange={onChangeHandler}
                hidden
            />
            <label htmlFor="raised-button-file">
                <Button component="span">
                    <FontAwesomeIcon icon={faUpload} className={classes.iconButton}/>
                    <Trans>Upload a file</Trans>
                </Button>
            </label>
        </React.Fragment>)
});