import * as React from "react";
import {HintButton, ModelInput} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {Divider, Grid, List, ListItem, ListItemSecondaryAction, ListItemText, Typography,} from "@material-ui/core";
import {t, Trans} from "@lingui/macro";


export const DateTimeFormatSettingsSection: React.FunctionComponent = observer(() => {
    const dateFormatHintText = [
        {key: 'YYYY', text: 'Year'},
        {key: 'MM', text: 'Month'},
        {key: 'DD', text: 'Day'}
    ]

    const timeFormatHintText = [
        {key: 'HH', text: 'Hours (24h)'},
        {key: 'hh', text: 'Hours (12h)'},
        {key: 'mm', text: 'Minutes'},
        {key: 'ss', text: 'Seconds'},
        {key: 'A', text: 'AM/PM'},
    ]

    const dateFormatHint = (textHints: { key: string, text: string }[]) => {
        return (
            <div>
                <List dense>
                    {textHints.map((hintText) => {
                        return (
                            <div>
                                <ListItem>
                                    <ListItemText
                                        primary={hintText.key}
                                    />
                                    <ListItemSecondaryAction>
                                        <Trans>
                                            {hintText.text}
                                        </Trans>
                                    </ListItemSecondaryAction>
                                </ListItem>
                                <Divider/>
                            </div>
                        )
                    })}
                </List>
                <h4>
                    <Trans>
                        Formatters are Case Sensitive
                    </Trans>
                </h4>
                <a href="https://momentjscom.readthedocs.io/en/latest/moment/04-displaying/01-format/" target="_blank"
                   rel="noopener noreferrer">
                    <Trans>
                        Moment library formatters
                    </Trans>
                </a>
            </div>
        )
    }

    return (
        <React.Fragment>
            <Grid container alignItems={'center'}>
                <Typography variant={"h5"}><Trans>Date & Time Format</Trans></Typography>
                <HintButton title={t`Date & Time Format`}
                            text={t`Changes how date and time is displayed throughout the application.`}/>
            </Grid>
            <ModelInput name={'date_format'}
                        hint={{title: t`Available Date Formatters`, children: dateFormatHint(dateFormatHintText)}}/>
            <ModelInput name={'time_format'}
                        hint={{title: t`Available Time Formatters`, children: dateFormatHint(timeFormatHintText)}}/>
            <ModelInput name={'date_time_separator'}/>
        </React.Fragment>
    )
})