import * as React from 'react';
import {BreadModel, makeBooleanColumn, makeColumn} from "@rx-suite/ui";
import {RxModuleComponentModel, RxModuleComponentStore} from "../../stores/RxModuleComponentStore";
import {AppForm} from "./AppForm";
import {t} from "@lingui/macro";
import {UpdateCell} from "../../components/apps/app_info/UpdateCell";
import {UpdateAllButton} from "../../components/apps/app_info/UpdateAllButton";
import {Observer} from "mobx-react-lite";

export const AppsBreadModel = () => {
    const columns = React.useMemo(() => {
        return [
            makeColumn('module_name', t`Module Name`, "string"),
            makeColumn('ip_address', t`IP Address`, "string"),
            makeColumn('port', t`Port`, "string"),
            makeColumn('type', t`App Type`, "string"),
            makeColumn('version', t`Current Version`, "string"),
            {
                Header: t`Update`,
                Cell: (row: { original: RxModuleComponentModel }) => <Observer>
                    {
                        () => {
                            const model = row.original as RxModuleComponentModel;
                            if (model) {
                                return <div style={{textAlign: 'center'}}><UpdateCell model={model}/></div>
                            } else {
                                return null;
                            }
                        }}</Observer>,
                sortable: false,
                width: 200
            },
            {
                Header: t`Update Info`,
                Cell: (row: { original: RxModuleComponentModel }) => <Observer>
                    {
                        () => {
                            const model = row.original as RxModuleComponentModel;
                            if (model) {
                                return <span title={model.updateText}>
                            {model.updateText.split("\n").map((v: string) => <React.Fragment
                                key={v}>{v}<br/></React.Fragment>)}
                        </span>;
                            } else {
                                return null;
                            }
                        }}</Observer>,
                sortable: false,
                width: 200
            },
            makeBooleanColumn('reachable', t`Online?`),
            makeBooleanColumn("licenced", t`Licenced?`)
        ]

    }, []);
    return (
        <BreadModel store={RxModuleComponentStore}
                    Form={AppForm}
                    columns={columns}
                    tableProps={{
                        preTableActions: <UpdateAllButton/>,
                        createText: t`Register`,
                        suppressWrapper: false,
                    }}
                    formProps={{
                        suppressWrapper: true
                    }}
        />
    );
};
