import * as React from 'react';
import {makeStyles} from "@material-ui/core/styles";
import {red} from "@material-ui/core/colors";
import {ButtonField} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {useSnackbar} from "notistack";
import {RxModuleComponentModel} from "../../stores/RxModuleComponentStore";

const useStyles = makeStyles({
    root: {
        backgroundColor: red[500]
    }
});

type Props = {
    model: RxModuleComponentModel
}

export const StopButton: React.FunctionComponent<Props> = ({model}) => {
    const classes = useStyles();
    const [loading, setLoading] = React.useState(false);
    const {enqueueSnackbar} = useSnackbar();

    const disabled = !model.reachable;

    const handleClick = React.useCallback(async () => {
        setLoading(true);

        try {
            await model.stop();
            enqueueSnackbar(t`Stop requested`, {variant: "success"});
        } catch {
            enqueueSnackbar(t`Couldn't request stop`, {variant: "error"});
        }

        setLoading(false);
    }, [enqueueSnackbar, model]);

    return (
        <ButtonField
            disabled={disabled}
            classes={classes}
            onClick={handleClick}
            text={t`Stop`}
            loading={loading}
        />
    )
};