import {attribute, DataStore, Model, model} from "@rx-suite/data";
import {t} from "@lingui/macro";
import * as yup from "yup";
import {observable, override} from "mobx";

@model({
    transportLayer: '/api/system_settings',
    permissionTarget: "SystemSetting",
    singleton: true,
    eager: true
})

export class SystemSettingModel extends Model {
    @attribute({
        label: t`Time Format`,
        validation: yup.string()
    })
    time_format = "HH:mm:ss";

    @attribute({
        label: t`Date Format`,
        validation: yup.string()
    })
    date_format = "YYYY/MM/DD";

    @attribute({
        label: t`Date Time Separator`,
        validation: yup.string()
    })
    date_time_separator = " - ";

    @attribute({
        label: t`Lens Tray Orientation`,
        validation: yup.number().integer().min(0).max(1)
    })
    lens_tray_orientation = 0;

    @attribute({
        label: t`Has Customer Logo`,
        validation: yup.boolean()
    })
    has_customer_logo = false;

    @attribute({
        label: t`clear logo`,
        validation: yup.boolean()
    })
    clear_logo = false;

    @observable file: Blob | undefined;

    /* Since the setting form includes files, we have to provide a custom commit */
    @override
    async commit(): Promise<void> {
        this.viewModel.submit();

        const formData = new FormData();
        formData.append('settings', JSON.stringify(this.asJson));
        if (this.file) {
            formData.append('logo', this.file as Blob);
        }

        const response = await SystemSettingStore.transportLayer.fetch(`/`, {
            method: 'POST',
            body: formData
        })
        return SystemSettingStore.transportLayer.parseJson(response);
    }

    constructor() {
        super();
        super.setup();
    }
}

export const SystemSettingStore = SystemSettingModel.store as unknown as DataStore<SystemSettingModel>;