# == Schema Information
#
# Table name: components
#
#  id                            :bigint           not null, primary key
#  delegate_requests_through_hub :boolean          default(FALSE)
#  description                   :string
#  external_address              :string
#  external_port                 :integer
#  has_token                     :boolean
#  has_update_available          :boolean
#  highest_available_update      :string
#  ip_address                    :string
#  is_api                        :boolean
#  is_updating                   :boolean
#  last_ping_at                  :datetime
#  last_ping_result              :text
#  last_successful_ping_at       :datetime
#  last_update_error             :string
#  licenced                      :boolean
#  module_name                   :string
#  port                          :integer
#  protocol                      :string           default("http")
#  reachable                     :boolean
#  token                         :string
#  type                          :string
#  update_status                 :string
#  version                       :string
#  created_at                    :datetime         not null
#  updated_at                    :datetime         not null
#  email_id                      :bigint
#  module_id                     :string
#
# Indexes
#
#  index_components_on_email_id             (email_id)
#  index_components_on_module_id            (module_id) UNIQUE
#  index_components_on_port_and_ip_address  (port,ip_address) UNIQUE
#
# Foreign Keys
#
#  fk_rails_...  (email_id => emails.id) ON DELETE => nullify
#
class RouterApiComponent < Component
  before_save :set_module_values

  def set_module_values
    self.module_id = module_identifier
    self.module_name = "Router API"
    self.description = "Manages the Router API for posting MES data from Rx-Data."
    self.is_api = true
  end

  def module_identifier
    "router_api"
  end

  def ping
    response = RxModule::Communicator.call_module_method(module_identifier, "/status", :get)
    assign_attributes({
      version: response[:version],
      reachable: true,
      licenced: true,
      last_successful_ping: Time.current
    })
  rescue
    Rails.logger.warn { {msg: "Component may be offline or returning invalid responses", component: as_json(except: :last_ping_result)} }
    assign_attributes(reachable: false)
  ensure
    self.last_ping_at = Time.current
    save
  end
end
